@@ -351,33 +351,6 @@ void       gnome_dialog_set_parent     (GnomeDialog * dialog,
   g_return_if_fail(parent != GTK_WINDOW(dialog));
 
   gtk_window_set_transient_for (GTK_WINDOW(dialog), parent);
-
-  /* FIXME!!!!!!!! */
-  /*if ( gnome_preferences_get_dialog_centered() ) { */
-  if (1) {
-
-    /* User wants us to center over parent */
-
-    gint x, y, w, h, dialog_x, dialog_y;
-
-    if ( ! GTK_WIDGET_VISIBLE(parent)) return; /* Can't get its
-						  size/pos */
-
-    /* Throw out other positioning */
-    gtk_window_set_position(GTK_WINDOW(dialog),GTK_WIN_POS_NONE);
-
-    gdk_window_get_origin (GTK_WIDGET(parent)->window, &x, &y);
-    gdk_drawable_get_size   (GTK_WIDGET(parent)->window, &w, &h);
-
-    /* The problem here is we don't know how big the dialog is.
-       So "centered" isn't really true. We'll go with
-       "kind of more or less on top" */
-
-    dialog_x = x + w/4;
-    dialog_y = y + h/4;
-
-    gtk_window_move (GTK_WINDOW (dialog), dialog_x, dialog_y);
-  }
 }
 
 
@@ -412,10 +385,11 @@ void       gnome_dialog_append_buttons (GnomeDialog * dialog,
 }
 
 /**
- * gnome_dialog_append_button: Add a button to a dialog after its initial construction.
+ * gnome_dialog_append_button:
  * @dialog: #GnomeDialog to add button to.
  * @button_name: Button to add.
  *
+ * Add a button to a dialog after its initial construction.
  * This function is mostly for internal library use. You should use
  * gnome_dialog_new() instead. See that function for a description of
  * the button argument.
@@ -490,11 +464,12 @@ gnome_pixmap_button(GtkWidget *pixmap, const char *text)
 
 
 /**
- * gnome_dialog_append_button_with_pixmap: Add a pixmap button to a dialog.
+ * gnome_dialog_append_button_with_pixmap:
  * @dialog: #GnomeDialog to add the button to.
  * @button_name: Name of the button, or stock button #define.
  * @pixmap_name: Stock pixmap name.
  *
+ * Add a pixmap button to a dialog.
  * gnome_dialog_new() does not permit custom buttons with pixmaps, so if you
  * want one of those you need to use this function.
  *
@@ -943,13 +918,13 @@ void       gnome_dialog_button_connect_object (GnomeDialog *dialog,
 
 
 /**
- * gnome_dialog_set_accelerator: Set an accelerator key for a button.
+ * gnome_dialog_set_accelerator:
  * @dialog: #GnomeDialog to affect.
  * @button: Button number.
  * @accelerator_key: Key for the accelerator.
  * @accelerator_mods: Modifier.
  *
- *
+ * Set an accelerator key for a button.
  **/
 void       gnome_dialog_set_accelerator(GnomeDialog * dialog,
 					gint button,
