@@ -160,17 +160,34 @@ static void
 dialog_show_callback (GtkWidget *widget, gpointer callback_data)
 {
 	GnomePasswordDialog *password_dialog;
+	GtkWidget *focus = NULL;
+	const gchar *text;
 
 	password_dialog = GNOME_PASSWORD_DIALOG (callback_data);
 
+	if (GTK_WIDGET_VISIBLE (password_dialog->details->password_entry))
+		/* Password is the default place to focus */
+		focus = password_dialog->details->password_entry;
+
+	if (GTK_WIDGET_VISIBLE (password_dialog->details->domain_entry) &&
+	    !password_dialog->details->readonly_domain) {
+		/* Empty domain entry gets focus */
+		text = gtk_entry_get_text (GTK_ENTRY (password_dialog->details->domain_entry));
+		if (!focus || !text || !text[0])
+			focus = password_dialog->details->domain_entry;
+	}
+
 	if (GTK_WIDGET_VISIBLE (password_dialog->details->username_entry) &&
 	    !password_dialog->details->readonly_username) {
-		gtk_widget_grab_focus (password_dialog->details->username_entry);
-	} else if (GTK_WIDGET_VISIBLE (password_dialog->details->domain_entry) &&
-		   !password_dialog->details->readonly_domain) {
-		gtk_widget_grab_focus (password_dialog->details->domain_entry);
-	} else if (GTK_WIDGET_VISIBLE (password_dialog->details->password_entry)) {
-		gtk_widget_grab_focus (password_dialog->details->password_entry);
+		/* Empty username entry gets focus */
+		text = gtk_entry_get_text (GTK_ENTRY (password_dialog->details->username_entry));
+		if (!focus || !text || !text[0])
+			focus = password_dialog->details->username_entry;
+	}
+
+	if (focus) {
+		gtk_widget_grab_focus (focus);
+		gtk_editable_select_region (GTK_EDITABLE (focus), 0, -1);
 	}
 }
 
@@ -203,7 +220,7 @@ add_row (GtkWidget *table, int row, const char *label_text, GtkWidget *entry, in
 	GtkWidget *label;
 
 	label = gtk_label_new_with_mnemonic (label_text);
-	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1,
@@ -287,6 +304,25 @@ domain_entry_activate (GtkWidget *widget, GtkWidget *dialog)
 
 
 /* Public GnomePasswordDialog methods */
+
+/**
+ * gnome_password_dialog_new:
+ * @dialog_title: The title of the dialog
+ * @message: Message text for the dialog
+ * @username: The username to be used in the dialog
+ * @password: Password to be used
+ * @readonly_username: Boolean value that controls whether the user
+ * can edit the username or not
+ * 
+ * Description: Creates a new password dialog with an optional title, 
+ * message, username, password etc. The user will be given the option to
+ * save the password for this session only or store it permanently in her
+ * keyring.
+ * 
+ * Returns: A new password dialog.
+ *
+ * Since: 2.4
+ **/
 GtkWidget *
 gnome_password_dialog_new (const char	*dialog_title,
 			   const char	*message,
@@ -307,7 +343,7 @@ gnome_password_dialog_new (const char	*dialog_title,
 	gtk_window_set_title (GTK_WINDOW (password_dialog), dialog_title);
 	gtk_dialog_add_buttons (GTK_DIALOG (password_dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_OK, GTK_RESPONSE_OK,
+				_("Co_nnect"), GTK_RESPONSE_OK,
 				NULL);
 
 	/* Setup the dialog */
@@ -315,6 +351,7 @@ gnome_password_dialog_new (const char	*dialog_title,
 
  	gtk_window_set_position (GTK_WINDOW (password_dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_modal (GTK_WINDOW (password_dialog), TRUE);
+	gtk_window_set_resizable (GTK_WINDOW (password_dialog), FALSE);
 
  	gtk_container_set_border_width (GTK_CONTAINER (password_dialog), DIALOG_BORDER_WIDTH);
 
@@ -332,7 +369,7 @@ gnome_password_dialog_new (const char	*dialog_title,
 			GTK_RADIO_BUTTON (password_dialog->details->connect_with_no_userpass_button));
         password_dialog->details->connect_with_userpass_button =
                 gtk_radio_button_new_with_mnemonic (
-			group, _("Connect as _user:"));
+			group, _("Connect as u_ser:"));
 
 	if (username != NULL && *username != 0) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (password_dialog->details->connect_with_userpass_button), TRUE);
@@ -430,9 +467,9 @@ gnome_password_dialog_new (const char	*dialog_title,
 	gtk_widget_show_all (GTK_DIALOG (password_dialog)->vbox);
 
 	password_dialog->details->remember_session_button =
-		gtk_check_button_new_with_label (_("Remember password for this session"));
+		gtk_check_button_new_with_mnemonic (_("_Remember password for this session"));
 	password_dialog->details->remember_forever_button =
-		gtk_check_button_new_with_label (_("Save password in keyring"));
+		gtk_check_button_new_with_mnemonic (_("Save password in _keyring"));
 
 	gtk_box_pack_start (GTK_BOX (vbox), password_dialog->details->remember_session_button, 
 			    TRUE, TRUE, 6);
@@ -461,6 +498,17 @@ gnome_password_dialog_run_and_block (GnomePasswordDialog *password_dialog)
 	return button_clicked == GTK_RESPONSE_OK;
 }
 
+/**
+ * gnome_password_dialog_set_username:
+ * @password_dialog: A #GnomePasswordDialog
+ * @username: The username that should be set
+ *
+ * Description: Sets the username in the password dialog.
+ *
+ * Returns:
+ *
+ * Since: 2.4
+ **/
 void
 gnome_password_dialog_set_username (GnomePasswordDialog	*password_dialog,
 				       const char		*username)
@@ -472,6 +520,17 @@ gnome_password_dialog_set_username (GnomePasswordDialog	*password_dialog,
 			    username?username:"");
 }
 
+/**
+ * gnome_password_dialog_set_password:
+ * @password_dialog: A #GnomePasswordDialog
+ * @password: The password that should be set
+ *
+ * Description: Sets the password in the password dialog.
+ *
+ * Returns:
+ *
+ * Since: 2.4
+ **/
 void
 gnome_password_dialog_set_password (GnomePasswordDialog	*password_dialog,
 				       const char		*password)
@@ -482,6 +541,17 @@ gnome_password_dialog_set_password (GnomePasswordDialog	*password_dialog,
 			    password ? password : "");
 }
 
+/**
+ * gnome_password_dialog_set_domain:
+ * @password_dialog: A #GnomePasswordDialog
+ * @domain: The domain that should be set
+ *
+ * Description: Sets the domain to be used in the password dialog.
+ *
+ * Returns:
+ *
+ * Since: 2.4
+ **/
 void
 gnome_password_dialog_set_domain (GnomePasswordDialog	*password_dialog,
 				  const char		*domain)
